Index: src/wp-admin/includes/class-wp-comments-list-table.php
===================================================================
--- src/wp-admin/includes/class-wp-comments-list-table.php	(revision 37647)
+++ src/wp-admin/includes/class-wp-comments-list-table.php	(working copy)
@@ -56,7 +56,7 @@

 	public function floated_admin_avatar( $name, $comment_ID ) {
 		$comment = get_comment( $comment_ID );
-		$avatar = get_avatar( $comment, 32, 'mystery' );
+		$avatar = get_avatar( $comment, 32, 'wapuu' );
 		return "$avatar $name";
 	}

Index: src/wp-admin/includes/comment.php
===================================================================
--- src/wp-admin/includes/comment.php	(revision 37647)
+++ src/wp-admin/includes/comment.php	(working copy)
@@ -172,7 +172,7 @@
  * @return string Avatar with Admin name.
  */
 function floated_admin_avatar( $name ) {
-	$avatar = get_avatar( get_comment(), 32, 'mystery' );
+	$avatar = get_avatar( get_comment(), 32, 'wapuu' );
 	return "$avatar $name";
 }

Index: src/wp-admin/includes/dashboard.php
===================================================================
--- src/wp-admin/includes/dashboard.php	(revision 37647)
+++ src/wp-admin/includes/dashboard.php	(working copy)
@@ -665,7 +665,7 @@

 		<li id="comment-<?php echo $comment->comment_ID; ?>" <?php comment_class( array( 'comment-item', wp_get_comment_status( $comment ) ), $comment ); ?>>

-			<?php echo get_avatar( $comment, 50, 'mystery' ); ?>
+			<?php echo get_avatar( $comment, 50, 'wapuu' ); ?>

 			<?php if ( !$comment->comment_type || 'comment' == $comment->comment_type ) : ?>

Index: src/wp-admin/includes/schema.php
===================================================================
--- src/wp-admin/includes/schema.php	(revision 37647)
+++ src/wp-admin/includes/schema.php	(working copy)
@@ -474,7 +474,7 @@
 	'medium_size_h' => 300,

 	// 2.6
-	'avatar_default' => 'mystery',
+	'avatar_default' => 'wapuu',

 	// 2.7
 	'large_size_w' => 1024,
Index: src/wp-admin/includes/upgrade.php
===================================================================
--- src/wp-admin/includes/upgrade.php	(revision 37647)
+++ src/wp-admin/includes/upgrade.php	(working copy)
@@ -191,12 +191,15 @@
 	$wpdb->insert( $wpdb->term_relationships, array('term_taxonomy_id' => $cat_tt_id, 'object_id' => 1) );

 	// Default comment
-	$first_comment_author = __('Mr WordPress');
+	$first_comment_author = __('A WordPress Commenter');
+	$first_comment_email = 'wapuu@wordpress.org';
 	$first_comment_url = 'https://wordpress.org/';
 	$first_comment = __('Hi, this is a comment.
-To delete a comment, just log in and view the post&#039;s comments. There you will have the option to edit or delete them.');
+To delete a comment, just log in and view the post&#039;s comments. There you will have the option to edit or delete them.
+Commenter avatars come from <a href="https://gravatar.com">Gravatar</a>.');
 	if ( is_multisite() ) {
 		$first_comment_author = get_site_option( 'first_comment_author', $first_comment_author );
+		$first_comment_email = get_site_option( 'first_comment_email', $first_comment_email );
 		$first_comment_url = get_site_option( 'first_comment_url', network_home_url() );
 		$first_comment = get_site_option( 'first_comment', $first_comment );
 	}
@@ -203,7 +206,7 @@
 	$wpdb->insert( $wpdb->comments, array(
 		'comment_post_ID' => 1,
 		'comment_author' => $first_comment_author,
-		'comment_author_email' => '',
+		'comment_author_email' => $first_comment_email,
 		'comment_author_url' => $first_comment_url,
 		'comment_date' => $now,
 		'comment_date_gmt' => $now_gmt,
Index: src/wp-admin/network/settings.php
===================================================================
--- src/wp-admin/network/settings.php	(revision 37647)
+++ src/wp-admin/network/settings.php	(working copy)
@@ -62,6 +62,7 @@
 		'first_post', 'first_page', 'first_comment', 'first_comment_url', 'first_comment_author',
 		'welcome_email', 'welcome_user_email', 'fileupload_maxk', 'global_terms_enabled',
 		'illegal_names', 'limited_email_domains', 'banned_email_domains', 'WPLANG', 'admin_email',
+		'first_comment_email',
 	);

 	// Handle translation install.
@@ -265,6 +266,15 @@
 				</td>
 			</tr>
 			<tr>
+				<th scope="row"><label for="first_comment_email"><?php _e( 'First Comment Email' ) ?></label></th>
+				<td>
+					<input type="text" size="40" name="first_comment_email" id="first_comment_email" aria-describedby="first-comment-email-desc" value="<?php echo esc_attr( get_site_option( 'first_comment_email' ) ); ?>" />
+					<p class="description" id="first-comment-email-desc">
+						<?php _e( 'The email address of the first comment author on a new site.' ) ?>
+					</p>
+				</td>
+			</tr>
+			<tr>
 				<th scope="row"><label for="first_comment_url"><?php _e( 'First Comment URL' ) ?></label></th>
 				<td>
 					<input type="text" size="40" name="first_comment_url" id="first_comment_url" aria-describedby="first-comment-url-desc" value="<?php echo esc_attr( get_site_option( 'first_comment_url' ) ) ?>" />
Index: src/wp-admin/options-discussion.php
===================================================================
--- src/wp-admin/options-discussion.php	(revision 37647)
+++ src/wp-admin/options-discussion.php	(working copy)
@@ -220,6 +220,7 @@

 <?php
 $avatar_defaults = array(
+	'wapuu' => __( 'Wapuu' ),
 	'mystery' => __('Mystery Person'),
 	'blank' => __('Blank'),
 	'gravatar_default' => __('Gravatar Logo'),
@@ -239,7 +240,7 @@
  * @param array $avatar_defaults Array of default avatars.
  */
 $avatar_defaults = apply_filters( 'avatar_defaults', $avatar_defaults );
-$default = get_option( 'avatar_default', 'mystery' );
+$default = get_option( 'avatar_default', 'wapuu' );
 $avatar_list = '';

 // Force avatars on to display these choices
Index: src/wp-includes/link-template.php
===================================================================
--- src/wp-includes/link-template.php	(revision 37647)
+++ src/wp-includes/link-template.php	(working copy)
@@ -3739,9 +3739,9 @@
  *     @type string $default        URL for the default image or a default type. Accepts '404' (return
  *                                  a 404 instead of a default image), 'retro' (8bit), 'monsterid' (monster),
  *                                  'wavatar' (cartoon face), 'indenticon' (the "quilt"), 'mystery', 'mm',
  *                                  or 'mysteryman' (The Oyster Man), 'blank' (transparent GIF), or
  *                                  'gravatar_default' (the Gravatar logo). Default is the value of the
  *                                  'avatar_default' option, with a fallback of 'mystery'.
  *     @type bool   $force_default  Whether to always show the default image, never the Gravatar. Default false.
  *     @type string $rating         What rating to display avatars up to. Accepts 'G', 'PG', 'R', 'X', and are
  *                                  judged in that order. Default is the value of the 'avatar_rating' option.
@@ -3773,9 +3773,9 @@
  *     @type string $default        URL for the default image or a default type. Accepts '404' (return
  *                                  a 404 instead of a default image), 'retro' (8bit), 'monsterid' (monster),
  *                                  'wavatar' (cartoon face), 'indenticon' (the "quilt"), 'mystery', 'mm',
  *                                  or 'mysteryman' (The Oyster Man), 'blank' (transparent GIF), or
  *                                  'gravatar_default' (the Gravatar logo). Default is the value of the
  *                                  'avatar_default' option, with a fallback of 'mystery'.
  *     @type bool   $force_default  Whether to always show the default image, never the Gravatar. Default false.
  *     @type string $rating         What rating to display avatars up to. Accepts 'G', 'PG', 'R', 'X', and are
  *                                  judged in that order. Default is the value of the 'avatar_rating' option.
@@ -3798,7 +3798,7 @@
 		'size'           => 96,
 		'height'         => null,
 		'width'          => null,
-		'default'        => get_option( 'avatar_default', 'mystery' ),
+		'default'        => get_option( 'avatar_default', 'wapuu' ),
 		'force_default'  => false,
 		'rating'         => get_option( 'avatar_rating' ),
 		'scheme'         => null,
@@ -3834,7 +3834,7 @@
 	}

 	if ( empty( $args['default'] ) ) {
-		$args['default'] = get_option( 'avatar_default', 'mystery' );
+		$args['default'] = get_option( 'avatar_default', 'wapuu' );
 	}

 	switch ( $args['default'] ) {
@@ -3739,9 +3739,9 @@
  *                                  a 404 instead of a default image), 'retro' (8bit), 'monsterid' (monster),
  *                                  'wavatar' (cartoon face), 'indenticon' (the "quilt"), 'mystery', 'mm',
- *                                  or 'mysteryman' (The Oyster Man), 'blank' (transparent GIF), or
+ *                                  or 'mysteryman' (The Oyster Man), 'wapuu', 'blank' (transparent GIF), or
  *                                  'gravatar_default' (the Gravatar logo). Default is the value of the
@@ -3739,9 +3739,9 @@
  *                                  'gravatar_default' (the Gravatar logo). Default is the value of the
- *                                  'avatar_default' option, with a fallback of 'mystery'.
+ *                                  'avatar_default' option, with a fallback of 'wapuu'.
  *     @type bool   $force_default  Whether to always show the default image, never the Gravatar. Default false.
  *     @type string $rating         What rating to display avatars up to. Accepts 'G', 'PG', 'R', 'X', and are
@@ -3773,9 +3773,9 @@
  *                                  a 404 instead of a default image), 'retro' (8bit), 'monsterid' (monster),
  *                                  'wavatar' (cartoon face), 'indenticon' (the "quilt"), 'mystery', 'mm',
- *                                  or 'mysteryman' (The Oyster Man), 'blank' (transparent GIF), or
+ *                                  or 'mysteryman' (The Oyster Man), 'wapuu', blank' (transparent GIF), or
  *                                  'gravatar_default' (the Gravatar logo). Default is the value of the
@@ -3773,9 +3773,9 @@
  *                                  'gravatar_default' (the Gravatar logo). Default is the value of the
- *                                  'avatar_default' option, with a fallback of 'mystery'.
+ *                                  'avatar_default' option, with a fallback of 'wapuu'.
  *     @type bool   $force_default  Whether to always show the default image, never the Gravatar. Default false.
  *     @type string $rating         What rating to display avatars up to. Accepts 'G', 'PG', 'R', 'X', and are
Index: src/wp-includes/pluggable.php
===================================================================
--- src/wp-includes/pluggable.php	(revision 37647)
+++ src/wp-includes/pluggable.php	(working copy)
@@ -2237,10 +2237,10 @@
  * @param int    $size       Optional. Height and width of the avatar image file in pixels. Default 96.
  * @param string $default    Optional. URL for the default image or a default type. Accepts '404'
  *                           (return a 404 instead of a default image), 'retro' (8bit), 'monsterid'
- *                           (monster), 'wavatar' (cartoon face), 'indenticon' (the "quilt"),
+ *                           (monster), 'wavatar' (cartoon face), 'indenticon' (the "quilt"), 'wapuu',
  *                           'mystery', 'mm', or 'mysteryman' (The Oyster Man), 'blank' (transparent GIF),
  *                           or 'gravatar_default' (the Gravatar logo). Default is the value of the
  *                           'avatar_default' option, with a fallback of 'mystery'.
  * @param string $alt        Optional. Alternative text to use in &lt;img&gt; tag. Default empty.
  * @param array  $args       {
  *     Optional. Extra arguments to retrieve the avatar.
@@ -2266,7 +2266,7 @@
 		'size'          => 96,
 		'height'        => null,
 		'width'         => null,
-		'default'       => get_option( 'avatar_default', 'mystery' ),
+		'default'       => get_option( 'avatar_default', 'wapuu' ),
 		'force_default' => false,
 		'rating'        => get_option( 'avatar_rating' ),
 		'scheme'        => null,
@@ -2237,10 +2237,10 @@
  *                           'mystery', 'mm', or 'mysteryman' (The Oyster Man), 'blank' (transparent GIF),
  *                           or 'gravatar_default' (the Gravatar logo). Default is the value of the
- *                           'avatar_default' option, with a fallback of 'mystery'.
+ *                           'avatar_default' option, with a fallback of 'wapuu'.
  * @param string $alt        Optional. Alternative text to use in &lt;img&gt; tag. Default empty.
  * @param array  $args       {
